Exception: CodeRay::NotStreamableError

Inherits:
Exception
  • Object
show all
Defined in:
lib/coderay.rb

Overview

This Exception is raised when you try to stream with something that is not capable of streaming.

Instance Method Summary collapse

Constructor Details

#initialize(obj) ⇒ NotStreamableError

Returns a new instance of NotStreamableError.



289
290
291
# File 'lib/coderay.rb', line 289

def initialize obj
	@obj = obj
end

Instance Method Details

#to_sObject



293
294
295
# File 'lib/coderay.rb', line 293

def to_s
	'%s is not Streamable!' % @obj.class
end