Module: CodeRay::Streamable
- Included in:
- Encoders::Count, Encoders::Debug, Encoders::Null, Encoders::Statistic, Encoders::Text, Encoders::Tokens, Encoders::XML, CodeRay::Scanners::Ruby
- Defined in:
- lib/coderay.rb
Overview
A dummy module that is included by subclasses of CodeRay::Scanner an CodeRay::Encoder to show that they are able to handle streams.